package Alien::Hush;
use strict;
use warnings;
use base qw( Alien::Base );

our $VERSION      = 0.8888;
# so other thing can ask us which version of Hush we have
our $HUSH_VERSION = '1.0.12';

=head1 NAME

Alien::Hush - Easily find or install the Hush cryptocoin full node

=head1 DESCRIPTION

Hush is a privacy coin that is the grandchild of Bitcoin and the
daughter of Zcash. In addition to *transparent* taddr's from the
Bitcoin world, there is now *shielded* addresses called zaddr's,
which are protected by Zero Knowledge mathematics known as zkSNARKs.

Learn more at the official Hush website: https://myhush.org

=head1 SYNOPSIS

Coming Soon

=head1 AUTHOR

Duke Leto <duke@leto.net>

=head1 SUPPORT THIS WORK

If you would like to support this work, because it helped you out
and your life is now amazing, feel free to send some donations to
the developer via the Hush blockchain :

HUSH: zcB3LvCwYPdvVmNmTvEFdFGwb4teocrPnVD8wvBgMn8ZKo5Vq9ypJLpAuqUM31hEbBnSHCjCpax5mjUi2HEM6NB8x7vfKrV

Cryptocoins make the world go round and round.

=head1 SUPPORTED PLATFORMS

Hush has upstream and up-upstream dependencies which are very fickle about which
operating systems they will compile on. If you would like to help make things
work on your platform, please contact us.

=head1 SEE ALSO

Bitcoin, Zcash, The Future

=head1 COPYRIGHT

Copyright (c) 2017 by Duke Leto <duke@leto.net>.  All rights reserved.

=head1 LICENSE AGREEMENT

This package is free software; you can redistribute it and/or
modify it under the same terms as Perl itself, Fuck Yeah.

=cut

8888.8888;
